==> haskell-hslogger-1.3.0.0-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslogger
version: 1.3.0.0
id: hslogger-1.3.0.0-DJ5wPp1pFXP7rSBTXf57N0
key: hslogger-1.3.0.0-DJ5wPp1pFXP7rSBTXf57N0
license: BSD-3-Clause
copyright: Copyright (c) 2004-2018 John Goerzen
           , (c) 2019      Herbert Valerio Riedel
maintainer: hvr@gnu.org
author: John Goerzen
homepage: https://github.com/hvr/hslogger/wiki
synopsis: Versatile logging framework
description:
    @hslogger@ is a logging framework for Haskell, roughly similar
    to [Python'\''s logging module](https://docs.python.org/2/library/logging.html).
    .
    @hslogger@ lets each log message have a priority and source be associated
    with it.  The programmer can then define global handlers that route
    or filter messages based on the priority and source.  @hslogger@ also
    has a [Syslog](https://tools.ietf.org/html/rfc5424) handler built in.
category: Interfaces
abi: f6979d1d70e05d1894c32e51dba47a7b
exposed: True
exposed-modules:
    System.Log System.Log.Formatter System.Log.Handler
    System.Log.Handler.Growl System.Log.Handler.Log4jXML
    System.Log.Handler.Simple System.Log.Handler.Syslog
    System.Log.Logger
hidden-modules: UTF8
import-dirs: /usr/lib/ghc-8.6.5/site-local/hslogger-1.3.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hslogger-1.3.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hslogger-1.3.0.0
hs-libraries: HShslogger-1.3.0.0-DJ5wPp1pFXP7rSBTXf57N0
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    network-2.8.0.0-1DkaUVvVIsp8sj7KmlE9xl
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78 time-1.8.0.2 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-hslogger/html/hslogger.haddock
haddock-html: /usr/share/doc/haskell-hslogger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslogger-1.3.0.0-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslogger
version: 1.3.0.0
id: hslogger-1.3.0.0-7phGxARUo0z713DdGy7dDO
key: hslogger-1.3.0.0-7phGxARUo0z713DdGy7dDO
license: BSD-3-Clause
copyright: Copyright (c) 2004-2018 John Goerzen
           , (c) 2019      Herbert Valerio Riedel
maintainer: hvr@gnu.org
author: John Goerzen
homepage: https://github.com/hvr/hslogger/wiki
synopsis: Versatile logging framework
description:
    @hslogger@ is a logging framework for Haskell, roughly similar
    to [Python'\''s logging module](https://docs.python.org/2/library/logging.html).
    .
    @hslogger@ lets each log message have a priority and source be associated
    with it.  The programmer can then define global handlers that route
    or filter messages based on the priority and source.  @hslogger@ also
    has a [Syslog](https://tools.ietf.org/html/rfc5424) handler built in.
category: Interfaces
abi: 1270b47723dfddbf73cbea6d36db9f4b
exposed: True
exposed-modules:
    System.Log System.Log.Formatter System.Log.Handler
    System.Log.Handler.Growl System.Log.Handler.Log4jXML
    System.Log.Handler.Simple System.Log.Handler.Syslog
    System.Log.Logger
hidden-modules: UTF8
import-dirs: /usr/lib/ghc-8.6.5/site-local/hslogger-1.3.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hslogger-1.3.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hslogger-1.3.0.0
hs-libraries: HShslogger-1.3.0.0-7phGxARUo0z713DdGy7dDO
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78 time-1.8.0.2 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-hslogger/html/hslogger.haddock
haddock-html: /usr/share/doc/haskell-hslogger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
